@@ -1,12 +1,12 @@
 # For now, hoist all functions to the top level
-from felt_python.maps import (
+from .maps import (
     create_map,
     delete_map,
     get_map_details,
     update_map,
 )
-from felt_python.exceptions import AuthError
-from felt_python.layers import (
+from .exceptions import AuthError
+from .layers import (
     list_layers,
     upload_file,
     upload_geodataframe,
@@ -16,13 +16,16 @@ from felt_python.layers import (
     refresh_url_layer,
     get_layer_details,
     update_layer_style,
+    get_export_link,
+    download_layer,
 )
-from felt_python.elements import (
+from .elements import (
     list_elements,
     list_element_groups,
     list_elements_in_group,
     post_elements,
     delete_element,
+    post_element_group,
 )
 
 __doc__ = """
@@ -50,10 +53,13 @@ __all__ = [
     "refresh_url_layer",
     "get_layer_details",
     "update_layer_style",
+    "get_export_link",
+    "download_layer",
     "AuthError",
     "list_elements",
     "list_element_groups",
     "list_elements_in_group",
     "post_elements",
     "delete_element",
+    "post_element_group",
 ]
